% Step test for Model 4 - Two CSTRs in Series
% Created by John Hedengren

global u

% Steady State Initial Conditions for the Controls
% Valve position at the outlet of the second reactor
u1_ss = 1.0;
% Heat transferred from the first reactor (Cooling)
u2_ss = 1.0;

% Steady State Initial Conditions for the States
V1_ss = 200.0;
CA1_ss = 0.0357;
T1_ss = 446.471;
V2_ss = 100.0;
CA2_ss = 0.0018;
T2_ss = 453.2585;
x_ss = [V1_ss;CA1_ss;T1_ss;V2_ss;CA2_ss;T2_ss];

% Open Loop Step Change
u = [2.0; 0.0];

% Final Time (min)
tf = 25;

[t,x] = ode15s('cstr4',[0 tf],x_ss);

% Volume of Reactors 1 & 2
V1 = x(:,1);
V2 = x(:,4);

% Temperature of Reactors 1 & 2
T1 = x(:,3);
T2 = x(:,6);

% Concentration of Reactors 1 & 2
C1 = x(:,2);
C2 = x(:,5);

% Plot the results
figure(1);
plot(t,V1,t,V2);
ylabel('Volume (L)');
xlabel('Time (min)');
legend('Reactor 1','Reactor 2');

figure(2)
plot(t,T1,t,T2);
ylabel('Temperature (K)');
xlabel('Time (min)');
legend('Reactor 1','Reactor 2');

figure(3)
plot(t,C1,t,C2);
ylabel('Concentration (mol/L)');
xlabel('Time (min)');
legend('Reactor 1','Reactor 2');

